using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Microsoft.SideShow;
using Microsoft.SideShow.SimpleContentFormat;

namespace SideShowContentCreator
{
    public partial class MainForm : Form
    {
        private readonly Guid s_gadgetId = 
            new Guid("{D1AC24B8-8349-4816-9270-5050C3D9009A}");

		private ScfSideShowGadget _gadget;

        public MainForm()
        {
            InitializeComponent();
			deleteMenuItemButton.Enabled = false;
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            UpdateImage();
			string iconPath = Environment.CurrentDirectory + "//icon.ico";
            GadgetRegistration.Register(false, s_gadgetId, 
                ScfSideShowGadget.ScfEndpointId,
                "Dr. Neil's SideShow Gadget", null,
				iconPath, 
                false, GadgetCachePolicies.KeepNewest,
                null);
			
			_gadget = new ScfSideShowGadget(s_gadgetId);
        }

        
//--------------------------------------------------------------------------------------
// Content Page Tab
//--------------------------------------------------------------------------------------

		private void contentAddContentButton_Click(object sender, EventArgs e)
		{
			if (_gadget != null)
			{
				_gadget.AddGlanceContent(glanceTextBox.Text);
				ScfAlign align = ScfAlign.Center;
				if (leftRadioButton.Checked)
				{
					align = ScfAlign.Left;
				}
				else if (rightRadioButton.Checked)
				{
					align = ScfAlign.Right;
				}

				Color txtColor = Color.White;
				string selectedColor = colorListBox.SelectedItem.ToString();
				switch (selectedColor)
				{
					case "Black":
						txtColor = Color.Black;
						break;
					case "Blue":
						txtColor = Color.Blue;
						break;
					case "Green":
						txtColor = Color.Green;
						break;
					case "Red":
						txtColor = Color.Red;
						break;
				}


				_gadget.AddContent(Scf.Content(
					(int)contentIdNumeric.Value,
					textTitleTextBox.Text,
					Scf.Txt(
						align, true,
					txtColor, textContentTextBox.Text),
					Scf.Btn(DeviceButton.Left,null,(int)contentIdNumeric.Value-1),
					Scf.Btn(DeviceButton.Right,null,(int)contentIdNumeric.Value+1)
					));
			}
		}

//--------------------------------------------------------------------------------------
// Image Page Tab
//--------------------------------------------------------------------------------------

		private void UpdateImage()
		{
			if (File.Exists(imageFileTextBox.Text))
			{
				imagePictureBox.Image = Bitmap.FromFile(imageFileTextBox.Text);
			}
		}

		private void fileSelectButton_Click(object sender, EventArgs e)
		{
			OpenFileDialog dlg = new OpenFileDialog();
			dlg.InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.MyPictures);
			dlg.Filter = "Image Files(*.bmp;*.jpg;*.gif)|*.bmp;*.jpg;*.gif|All Files (*.*)|*.*";

			DialogResult result = dlg.ShowDialog();

			if (result == DialogResult.OK)
			{
				imageFileTextBox.Text = dlg.FileName;
				UpdateImage();
			}

		}

		private void imageAddContentButton_Click(object sender, EventArgs e)
		{
			if (_gadget != null)
			{
				_gadget.AddGlanceContent(glanceTextBox.Text);

				ScfAlign align = ScfAlign.Center;
				if (imgLeftRadioButton.Checked)
				{
					align = ScfAlign.Left;
				}
				else if (imgRightRadioButton.Checked)
				{
					align = ScfAlign.Right;
				}

				ScfImageFit fit = ScfImageFit.Auto;
				if (nativeFitRadioButton.Checked)
				{
					fit = ScfImageFit.Native;
				}
				else if (screenFitRadioButton.Checked)
				{
					fit = ScfImageFit.Screen;
				}
				else if (widthFitRadioButton.Checked)
				{
					fit = ScfImageFit.Width;
				}

				int imageContentID = 10000 + (int)ImageContentIdNumeric.Value;

				_gadget.AddContent(Scf.Content(
					(int)ImageContentIdNumeric.Value, 
					imageTitleTextBox.Text,
					Scf.Img(imageContentID, 
					align,
					fit, 
					"Image cannot be displayed"),
					Scf.Btn(DeviceButton.Left, 
					    null, (int)ImageContentIdNumeric.Value - 1),
					Scf.Btn(DeviceButton.Right, 
					    null, (int)ImageContentIdNumeric.Value + 1)
					));

				_gadget.AddContent(imageContentID,
					ImageContentTransforms.ReduceColorDepth
					| ImageContentTransforms.KeepAspectRatio 
					| ImageContentTransforms.StretchToFit
					,imagePictureBox.Image);
			}
		}

//--------------------------------------------------------------------------------------
// Menu Page Tab
//--------------------------------------------------------------------------------------

		private void menuItemListView_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (menuItemListView.SelectedItems.Count > 0)
			{
				deleteMenuItemButton.Enabled = true;
			}
			else
			{
				deleteMenuItemButton.Enabled = false;
			}
		}

		private void addMenuItemButton_Click(object sender, EventArgs e)
		{
			AddMenuItemDlg dlg = new AddMenuItemDlg();
			DialogResult result = dlg.ShowDialog();

			if (result == DialogResult.OK)
			{
				string[] itemStrings = new string[2];
				itemStrings[0] = dlg.TargetID.ToString();
				itemStrings[1] = dlg.MenuText;

				ListViewItem menuItem = new ListViewItem(itemStrings);

				menuItemListView.Items.Add(menuItem);
			}

		}

		private void deleteMenuItemButton_Click(object sender, EventArgs e)
		{
			if (menuItemListView.SelectedItems.Count > 0)
			{
				foreach (ListViewItem item in menuItemListView.SelectedItems)
				{
					menuItemListView.Items.Remove(item);
				}
			}
			else
			{
				deleteMenuItemButton.Enabled = false;
			}
		}

		private void menuAddContentButton_Click(object sender, EventArgs e)
		{
			if (_gadget != null)
			{
				_gadget.AddGlanceContent(glanceTextBox.Text);


				ScfElement[] menuItems = new ScfElement[menuItemListView.Items.Count];
				int menuIndex = 0;
				foreach (ListViewItem item in menuItemListView.Items)
				{
					int targetID = int.Parse(item.SubItems[0].Text);
					string menuText = item.SubItems[1].Text;
					menuItems[menuIndex] = Scf.Item(targetID, menuText);
					menuIndex++;
				}
				
				_gadget.AddContent(Scf.Menu(
					(int)menuContentIdNumeric.Value,
					menuTitleTextBox.Text,
					ScfSelectAction.Target,
					menuItems
					));
			}
		}

//--------------------------------------------------------------------------------------
// Dialog Page Tab
//--------------------------------------------------------------------------------------

		private void buttonsListView_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (buttonsListView.SelectedItems.Count > 0)
			{
				deleteButtonButton.Enabled = true;
			}
			else
			{
				deleteButtonButton.Enabled = false;
			}
		}

		private void deleteButtonButton_Click(object sender, EventArgs e)
		{
			if (buttonsListView.SelectedItems.Count > 0)
			{
				foreach (ListViewItem item in buttonsListView.SelectedItems)
				{
					buttonsListView.Items.Remove(item);
				}
			}
			else
			{
				deleteButtonButton.Enabled = false;
			}
		}

		private void addButtonButton_Click(object sender, EventArgs e)
		{
			AddButtonDlg dlg = new AddButtonDlg();
			DialogResult result = dlg.ShowDialog();

			if (result == DialogResult.OK)
			{
				
				string[] itemStrings = new string[3];
				itemStrings[0] = dlg.DeviceButton.ToString();
				itemStrings[1] = dlg.ButtonText;
				itemStrings[2] = dlg.TargetID.ToString();

				ListViewItem buttonItem = new ListViewItem(itemStrings);
				buttonItem.SubItems[0].Tag = (int)dlg.DeviceButton;
				buttonsListView.Items.Add(buttonItem);
			}
		}

		private void dialogAddContentButton_Click(object sender, EventArgs e)
		{
			if (_gadget != null)
			{
				_gadget.AddGlanceContent(glanceTextBox.Text);

				ScfElement[] dlgItems = new ScfElement[buttonsListView.Items.Count+1];

				int btnIndex = 0;

				dlgItems[btnIndex] = Scf.Txt(ScfAlign.Center, true, Color.White, dialogContentTextBox.Text);
				btnIndex++;

				foreach (ListViewItem item in buttonsListView.Items)
				{
					Microsoft.SideShow.DeviceButton devBtn = 
						(Microsoft.SideShow.DeviceButton)item.SubItems[0].Tag;

					//this is a hack as the Scf.Btn method doesnt take anything but Enter
					// in this version of the DLL
					// which is a BUG I assume!
					devBtn = DeviceButton.Enter; 
					
					string btnText = item.SubItems[1].Text;
					int targetID = int.Parse(item.SubItems[2].Text);
					dlgItems[btnIndex] = 
						Scf.Btn((Microsoft.SideShow.DeviceButton)devBtn, 
						btnText, targetID);
					btnIndex++;
				}

				_gadget.AddContent(Scf.Dialog(
					(int)dialogContentNumeric.Value,
					dialogTitleTextBox.Text,
					dlgItems
					));
			}
		}

		

		
    }
}